@@ -3,7 +3,7 @@ package Mnet;
 # version number used by Makefile.PL
 #   these should be set to "dev", expect when creating a new release
 #   refer to developer build notes in Makefile.PL for more info
-our $VERSION = "5.08";
+our $VERSION = "5.09";
 
 =head1 NAME
 
@@ -18,9 +18,9 @@ Mnet - Testable network automation and reporting
     #
     #   use --help to list all options, or --help <option>
     #   use --device <address> to connect to device with logging
-    #   use --batch <file.batch> to process one --device per line
-    #   add --report csv:<file.csv> to create an output csv file
-    #   add --record <file.test> to create a --device test file
+    #   use --batch <file.batch> to process multiple --device lines
+    #   add --report csv:<file.csv> to create output csv repory file
+    #   add --record <file.test> to create replayable test file
     #   use --test --replay <file.test> to show script test diff
 
     # load modules
@@ -34,7 +34,7 @@ Mnet - Testable network automation and reporting
     use Mnet::Stanza;
     use Mnet::Test;
 
-    # define --device name and --report output cli options
+    # define --device related and --report cli options
     #   options can also be set via Mnet environment variable
     Mnet::Opts::Cli::define({ getopt => "device=s" });
     Mnet::Opts::Cli::define({ getopt => "username=s" });
@@ -56,11 +56,14 @@ Mnet - Testable network automation and reporting
     });
 
     # handle concurrent --batch processing, parent exits when finished
-    #   process a list of thousands of devices, hundreds at a time, etc
+    #   process one device or ten thousand devices with the same script
+
+    # read command line options, fork children if in --batch mode
+    #   exit --batch parent process when finished forking children
     $cli = Mnet::Batch::fork($cli);
     exit if not $cli;
 
-    # ensure that errors are reported if script aborts for any reason
+    # ensure that errors are reported if script aborts before finishing
     $report->row_on_error({ device => $cli->device });
 
     # use log function and set up log object for device
@@ -69,7 +72,7 @@ Mnet - Testable network automation and reporting
     $log->info("processing device");
 
     # create an expect ssh session to --device
-    #   perldoc Mnet::Expect shows how to disable ssh host/key checks
+    #   see perldoc Mnet::Expect::Cli::Ios to disable ssh host/key checks
     my $ssh = Mnet::Expect::Cli::Ios->new({
         spawn => [ "ssh", $cli->{device} ],
     });
@@ -78,14 +81,14 @@ Mnet - Testable network automation and reporting
     my $config = $ssh->command("show running-config");
     WARN("unable to read config") if not $config;
 
-    # retrieve interface vlan 1 stanza from config
+    # parse interface loopack0 stanza from config
     my $loop = Mnet::Stanza::parse($config, qr/^interface loopback0$/i);
 
-    # parse primary ip address from loopback config
+    # parse primary ip address from loopback0 config stanza
     my $ip = undef;
     $ip = $1 if $loop and $loop =~ /^ ip address (\S+) \S+$/m;
 
-    # report on parsed loopback interface ip addres
+    # report on parsed loopback0 interface ip addres
     $report->row({ device => $cli->device, ip => $ip });
 
     # finished
@@ -131,7 +134,7 @@ of automation scripts and allowing for proper regression testing.
 
 =back
 
-Most of the L<Mnet> isub-modules can be used independently of each other,
+Most of the L<Mnet> sub-modules can be used independently of each other,
 unless otherwise noted.
 
 Refer to the individual modules listed in the SEE ALSO section below
@@ -152,8 +155,7 @@ Or downloaded and installed from L<https://github.com/menzascripting/Mnet>
     perl Makefile.PL  # INSTALL_BASE=/specify/path
     make install
 
-You might need to update your PERL5LIB environment variable if you uncommented
-the INSTALL_BASE option above.
+Check your PERL5LIB environment variable if INSTALL_BASE was used, above.
 
 =head1 AUTHOR
 
@@ -180,8 +182,6 @@ this program. If not, see L<http://www.gnu.org/licenses/>
 
 L<Mnet::Batch>
 
-L<Mnet::Expect>
-
 L<Mnet::Expect::Cli>
 
 L<Mnet::Expect::Cli::Ios>
@@ -190,11 +190,7 @@ L<Mnet::Log>
 
 L<Mnet::Opts::Cli>
 
-L<Mnet::Opts::Set::Debug>
-
-L<Mnet::Opts::Set::Quiet>
-
-L<Mnet::Opts::Set::Silent>
+L<Mnet::Opts::Set>
 
 L<Mnet::Report::Table>
 
