@@ -74,7 +74,7 @@ INIT {
     # define --help cli option
     Mnet::Opts::Cli::define({
         getopt      => 'help:s',
-        help_tip    => 'display tips, or matching option text',
+        help_tip    => 'display option help, *try --help help',
         norecord    => 1,
     });
 
@@ -123,10 +123,11 @@ The following keys in the specs input hash reference argument are supported:
 
     getopt      required option name and type, see perldoc Getopt::Long
     default     default value for option, defaults to undefined
+    help_hide   set to hide option in --help list of available options
     help_tip    short tip text for --help list of available options
     help_text   longer help text to show in --help for specific options
     norecord    set so option is not saved to Mnet::Test record/replay
-    redact      set to revent option value from displaying in Mnet::Log
+    redact      set to prevent option value from displaying in Mnet::Log
 
 Refer to L<Getopt::Long> for more information.
 
@@ -138,8 +139,8 @@ Refer to L<Getopt::Long> for more information.
 
     # check for required getopt key in input specs, note opt name
     croak("missing specs hash getopt key") if not defined $specs->{getopt};
-    croak("invalid specs hash getopt value")
-        if $specs->{getopt} !~ /^([a-z][-a-z0-9]+)/;
+    croak("invalid specs hash getopt value $specs->{getopt}")
+        if $specs->{getopt} !~ /^([a-z0-9](-|[a-z0-9])*)(!|=i|:i|=s|:s)?$/;
     my $opt = $1;
 
     # abort if option was already defined
@@ -200,9 +201,9 @@ sub new {
     $opts = Mnet::Opts::Cli->new()
     or ($cli, @extras) = Mnet::Opts::Cli->new()
 
-The class method may be used to retrieve an options object containing defined
-options parsed from the command line and an array contining any extra command
-line arguments.
+The new class method may be used to retrieve an options object containing
+defined options parsed from the command line and an array contining any extra
+command line arguments.
 
 If called in list context this method will return an opts object containing
 values for defined options parsed from the command line followed by a list of
@@ -211,7 +212,7 @@ any other extra arguments that were present on the command line.
     use Mnet::Opts::Cli;
     my ($cli, @extras) = Mnet::Opts::Cli->new();
 
-If called in scalar context an error will be issued if extra command line
+If not called in list context an error will be issued if extra command line
 arguments exist.
 
     use Mnet::Opts::Cli;
@@ -385,8 +386,8 @@ The perl ARGV array is not modified by this module.
     foreach my $opt (sort keys %{$Mnet::Opts::Cli::defined}) {
         my $defined_opt = $Mnet::Opts::Cli::defined->{$opt};
 
-        # options can be reset to with --reset cli option
-        if ($cli_opts->{reset} and $cli_opts->{reset} eq $opt) {
+        # options can be reset with --test-reset cli option
+        if ($cli_opts->{'test-reset'} and $cli_opts->{'test-reset'} eq $opt) {
             $log_entries->{$opt} = "def";
             $opts->{$opt} = $defined_opt->{default};
 
@@ -454,7 +455,7 @@ The perl ARGV array is not modified by this module.
     }
 
     # output extra cli arg error when not called to return extras args
-    die "invalid extra args @extras\n" if $extras[0] and not wantarray;
+    die "invalid or missing args @extras\n" if $extras[0] and not wantarray;
 
     # get test data hash ref from Mnet::Test module
     #   init to empty dummy hash ref if Mnet::Test not loaded
@@ -479,8 +480,8 @@ The perl ARGV array is not modified by this module.
     if (defined $extras[0]) {
         $log->debug("new extra cli args will record from command line");
         $test_data->{extras} = \@extras;
-    } elsif (defined $opts->{reset} and $opts->{reset} eq "") {
-        $log->debug("new extra cli args will record as reset to --reset");
+    } elsif (defined $opts->{'test-reset'} and $opts->{'test-reset'} eq ""){
+        $log->debug("new extra cli args will reset via --test-reset");
         delete $test_data->{extras};
     } elsif (exists $test_data->{extras}) {
         $log->debug("new extra cli args will replay from Mnet::Test data");
@@ -527,7 +528,7 @@ sub _new_help {
     my $output = "\n";
 
     # output list of help usage tips, one line per option
-    if ($help eq "") {
+    if ($help eq "" or $help eq "help") {
 
         # calculate width to align usage and tip columns
         my $width = 0;
@@ -542,6 +543,7 @@ sub _new_help {
             my ($width, $defined_opt) = (shift, shift);
             my $usage = $defined_opt->{help_usage};
             my $tip = $defined_opt->{help_tip} // "";
+            $tip = "*$tip" if $defined_opt->{help_hide};
             return sprintf(" --%-${width}s   $tip\n", $usage);
         }
 
@@ -549,8 +551,9 @@ sub _new_help {
         my $other_options = "";
         foreach my $opt (sort keys %{$Mnet::Opts::Cli::defined}) {
             my $defined_opt = $Mnet::Opts::Cli::defined->{$opt};
+            next if $help ne "help" and $defined_opt->{help_hide};
             next if $defined_opt->{caller} =~ /^Mnet(::|$)/;
-            $other_options = "Script options:\n\n" if not $other_options;
+            $other_options = "Script option:\n\n" if not $other_options;
             $other_options .= _new_help_tip($width, $defined_opt);
         }
         $output .= "$other_options\n" if $other_options;
@@ -559,6 +562,7 @@ sub _new_help {
         $output .= "Mnet options:\n\n";
         foreach my $opt (sort keys %{$Mnet::Opts::Cli::defined}) {
             my $defined_opt = $Mnet::Opts::Cli::defined->{$opt};
+            next if $help ne "help" and $defined_opt->{help_hide};
             next if $defined_opt->{caller} !~ /^Mnet(::|$)/;
             $output .= _new_help_tip($width, $defined_opt);
         }
@@ -647,7 +651,7 @@ When used with the L<Mnet::Test> --record option this module will save all cli
 options defined without the norecord hash key set true in the specified file
 along with any extra arguments specified on the command line. For more info
 about enabling the recording of individual options refer to the define
-function in this module and the --reset option.
+function in this module and the --test-reset option.
 
 When the --replay option is used this module will load all cli options saved
 in the specified Mnet::Test file then apply options specified on the command
